# -*- coding: utf-8 -*-
#
# ownCloud Univention package
#  config registry module to update ownCloud configuration
#
# Copyright 2013 ownCloud Inc.
#
# http://www.owncloud.com/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

import os

def handler(configRegistry, changes):
	configfile = "/var/www/owncloud/config/config.php"
	for key in changes:
		if type(changes[key]) is not tuple:
			continue
		if changes[key][0] != changes[key][1]:
			#First, handle variables that affect configuration in database
			configvalue = changes[key][-1]

			funcParam = ""

			if key == "owncloud/user/quota":
				configkey = "ldap_quota_def"
			elif key == "owncloud/ldap/group/displayName":
				configkey = "ldap_group_display_name"
			elif key == "owncloud/ldap/group/searchAttributes":
				configkey = "ldap_attributes_for_group_search"
				configvalue = "REPLACE('" + configvalue + "', ',', '\n')"
				funcParam = "--func"
			elif key == "owncloud/ldap/groupMemberAssoc":
				configkey = "ldap_group_member_assoc_attribute"
			elif key == "owncloud/ldap/tls":
				configkey = "ldap_tls"
			elif key == "owncloud/ldap/cacheTTL":
				configkey = "ldap_cache_ttl"
			elif key == "owncloud/ldap/disableMainServer":
				configkey = "ldap_override_main_server"
			elif key == "owncloud/ldap/displayName":
				configkey = "ldap_display_name"
			elif key == "owncloud/ldap/base/users":
				configkey = "ldap_base_users"
			elif key == "owncloud/ldap/base/groups":
				configkey = "ldap_base_groups"
			elif key == "owncloud/ldap/loginFilter":
				configkey = "ldap_login_filter"
			elif key == "owncloud/ldap/userlistFilter":
				configkey = "ldap_userlist_filter"
			elif key == "owncloud/ldap/groupFilter":
				configkey = "ldap_group_filter"
			elif key == "owncloud/ldap/user/quotaAttribute":
				configkey = "ldap_quota_attr"
			elif key == "owncloud/ldap/user/homeAttribute":
				configkey = "home_folder_naming_rule"
				if configvalue:
					configvalue = "attr:" + configvalue
			elif key == "owncloud/ldap/user/searchAttributes":
				configkey = "ldap_attributes_for_user_search"
				configvalue = "REPLACE('" + configvalue + "', ',', '\n')"
				funcParam = "--func"
			else:
				configkey = False

			if configkey:
				if not os.path.isfile(configfile):
					continue
				cmd = "/usr/share/owncloud/update-ldap-config.sh '" + configkey + "' \"" + configvalue + "\" " + funcParam
				os.system(cmd)
				continue

			#Handle variables that affect configuration in config file
			if not os.path.isfile(configfile):
				continue;
			if key == "owncloud/directory/data":
				match = ".*'datadirectory'.*"
				replace = "  'datadirectory' => '" + configvalue + "',"
				cmd = "sed -i \"s|" + match + "|" + replace + "|g\" " + configfile
				os.system(cmd)
				continue

			#Handle variables that affect configuration in LDAP
			if key == "owncloud/user/enabled":
				cmd = "univention-directory-manager settings/extended_attribute modify --dn \"cn=ownCloudUserEnabled,cn=owncloud,cn=custom attributes,cn=univention," + configRegistry['ldap/base'] + "\" --set default=\"" + configvalue + "\" || true"
			elif key == "owncloud/group/enabled":
				cmd = "univention-directory-manager settings/extended_attribute modify --dn \"cn=ownCloudGroupEnabled,cn=owncloud,cn=custom attributes,cn=univention," + configRegistry['ldap/base'] + "\" --set default=\"" + configvalue + "\" || true"
			else:
				cmd = False

			if cmd:
				os.system(cmd)
				continue
